#[repr(C)]pub struct Lock<T: ?Sized, B: Backend> { /* private fields */ }Expand description
A mutual exclusion primitive.
Exposes one of the kernel locking primitives. Which one is exposed depends on the lock
Backend specified as the generic parameter B.
Implementations
Sourceimpl<B: Backend> Lock<(), B>
impl<B: Backend> Lock<(), B>
Sourcepub unsafe fn from_raw<'a>(ptr: *mut B::State) -> &'a Self
pub unsafe fn from_raw<'a>(ptr: *mut B::State) -> &'a Self
Constructs a Lock from a raw pointer.
This can be useful for interacting with a lock which was initialised outside of Rust.
Safety
The caller promises that ptr points to a valid initialised instance of State during
the whole lifetime of 'a.
- the memory range
[, + sizeof()*]must be fully initialized for type ``